@@ -1,14 +1,9 @@
 // Copyright (C) 2009-2012 NICTA (www.nicta.com.au)
 // Copyright (C) 2009-2012 Conrad Sanderson
 // 
-// This file is part of the Armadillo C++ library.
-// It is provided without any warranty of fitness
-// for any purpose. You can redistribute this file
-// and/or modify it under the terms of the GNU
-// Lesser General Public License (LGPL) as published
-// by the Free Software Foundation, either version 3
-// of the License or (at your option) any later version.
-// (see http://www.opensource.org/licenses for more info)
+// This Source Code Form is subject to the terms of the Mozilla Public
+// License, v. 2.0. If a copy of the MPL was not distributed with this
+// file, You can obtain one at http://mozilla.org/MPL/2.0/.
 
 
 //! \addtogroup fn_prod
@@ -28,17 +23,17 @@ arma_inline
 const Op<T1, op_prod>
 prod
   (
-  const Base<typename T1::elem_type,T1>& X,
+  const T1& X,
   const uword dim = 0,
-  const typename enable_if<resolves_to_vector<T1>::value == false>::result* junk1 = 0,
-  const typename enable_if<is_basevec<T1>::value == false>::result* junk2 = 0
+  const typename enable_if< is_arma_type<T1>::value       == true  >::result* junk1 = 0,
+  const typename enable_if< resolves_to_vector<T1>::value == false >::result* junk2 = 0
   )
   {
   arma_extra_debug_sigprint();
   arma_ignore(junk1);
   arma_ignore(junk2);
   
-  return Op<T1, op_prod>(X.get_ref(), dim, 0);
+  return Op<T1, op_prod>(X, dim, 0);
   }
 
 
@@ -48,7 +43,7 @@ arma_inline
 const Op<T1, op_prod>
 prod
   (
-  const Base<typename T1::elem_type,T1>& X,
+  const T1& X,
   const uword dim,
   const typename enable_if<resolves_to_vector<T1>::value == true>::result* junk = 0
   )
@@ -56,7 +51,27 @@ prod
   arma_extra_debug_sigprint();
   arma_ignore(junk);
   
-  return Op<T1, op_prod>(X.get_ref(), dim, 0);
+  return Op<T1, op_prod>(X, dim, 0);
+  }
+
+
+
+template<typename T1>
+inline
+arma_warn_unused
+typename T1::elem_type
+prod
+  (
+  const T1& X,
+  const arma_empty_class junk1 = arma_empty_class(),
+  const typename enable_if<resolves_to_vector<T1>::value == true>::result* junk2 = 0
+  )
+  {
+  arma_extra_debug_sigprint();
+  arma_ignore(junk1);
+  arma_ignore(junk2);
+  
+  return op_prod::prod( X );
   }
 
 
@@ -67,6 +82,7 @@ prod
 
 template<typename T1>
 inline
+arma_warn_unused
 typename T1::elem_type
 prod(const Op<T1, op_prod>& in)
   {
@@ -90,46 +106,6 @@ prod(const Op<T1, op_prod>& in, const uword dim)
 
 
 
-template<typename T1>
-inline
-arma_warn_unused
-typename T1::elem_type
-prod
-  (
-  const Base<typename T1::elem_type,T1>& X,
-  const arma_empty_class junk1 = arma_empty_class(),
-  const typename enable_if<resolves_to_vector<T1>::value == true>::result* junk2 = 0
-  )
-  {
-  arma_extra_debug_sigprint();
-  arma_ignore(junk1);
-  arma_ignore(junk2);
-  
-  return op_prod::prod( X.get_ref() );
-  }
-
-
-
-template<typename T1>
-inline
-arma_warn_unused
-typename T1::elem_type
-prod
-  (
-  const T1& X,
-  const arma_empty_class junk1 = arma_empty_class(),
-  const typename enable_if<is_basevec<T1>::value == true>::result* junk2 = 0
-  )
-  {
-  arma_extra_debug_sigprint();
-  arma_ignore(junk1);
-  arma_ignore(junk2);
-  
-  return op_prod::prod(X);
-  }
-
-
-
 template<typename T>
 arma_inline
 arma_warn_unused
